@@ -1,18 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KPIMTEXTEDITRICHTEXTCOMPOSER_H
-#define KPIMTEXTEDITRICHTEXTCOMPOSER_H
+#pragma once
 
 #include "kpimtextedit_export.h"
 
 #include <kpimtextedit/richtexteditor.h>
 class KActionCollection;
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class RichTextComposerControler;
 class RichTextComposerActions;
 class RichTextExternalComposer;
@@ -29,8 +29,8 @@ public:
     ~RichTextComposer() override;
 
     enum Mode {
-        Plain,    ///< Plain text mode
-        Rich      ///< Rich text mode
+        Plain, ///< Plain text mode
+        Rich ///< Rich text mode
     };
 
     /**
@@ -78,8 +78,8 @@ public:
     Q_REQUIRED_RESULT bool checkExternalEditorFinished();
     void killExternalEditor();
 
-    //Redefine it for each apps
-    virtual QString smartQuote(const QString &msg);    //need by kmail
+    // Redefine it for each apps
+    virtual QString smartQuote(const QString &msg); // need by kmail
 
     void setQuotePrefixName(const QString &quotePrefix);
     Q_REQUIRED_RESULT QString quotePrefixName() const;
@@ -97,7 +97,7 @@ public:
     KPIMTextEdit::RichTextExternalComposer *externalComposer() const;
     KPIMTextEdit::RichTextComposerActions *composerActions() const;
     void createHighlighter() override;
-    virtual bool processModifyText(QKeyEvent *event);
+    Q_REQUIRED_RESULT virtual bool processModifyText(QKeyEvent *event);
 
 public Q_SLOTS:
     void insertPlainTextImplementation();
@@ -136,7 +136,6 @@ private:
     void evaluateListSupport(QKeyEvent *event);
     void evaluateReturnKeySupport(QKeyEvent *event);
     class RichTextComposerPrivate;
-    RichTextComposerPrivate *const d;
+    std::unique_ptr<RichTextComposerPrivate> const d;
 };
 }
-#endif // RICHTEXTCOMPOSER_H
